@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from distutils.spawn import find_executable
 
 from django.utils.functional import cached_property
@@ -33,6 +35,7 @@ class RhinoEnvironment(Environment):
         # Start of the command to run the compiler in Java.
         return [
             "java",
+            "-Xss1M",
             "-classpath",
             ":".join((
                 self.env.resource_path("js.jar"),
