@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 import tempfile, shutil, os.path, hashlib, subprocess
 from functools import partial
 from contextlib import closing
@@ -67,7 +69,7 @@ class OptimizedFilesMixin(object):
     REQUIRE_COPY_BLOCK_SIZE = 1024*1024  # 1 MB.
 
     def _file_iter(self, handle):
-        return iter(partial(handle.read, self.REQUIRE_COPY_BLOCK_SIZE), "")
+        return iter(partial(handle.read, self.REQUIRE_COPY_BLOCK_SIZE), b'')
 
     def post_process(self, paths, dry_run=False, verbosity=1, **options):
         # If this is a dry run, give up now!
@@ -94,16 +96,17 @@ class OptimizedFilesMixin(object):
                 # Store details of file.
                 compile_info[name] = hash.digest()
             # Run the optimizer.
-            if require_settings.REQUIRE_BUILD_PROFILE is not None:
-                app_build_js_path = env.compile_dir_path(require_settings.REQUIRE_BUILD_PROFILE)
-            else:
-                app_build_js_path = env.resource_path("app.build.js")
-            env.run_optimizer(
-                app_build_js_path,
-                dir = env.build_dir,
-                appDir = env.compile_dir,
-                baseUrl = require_settings.REQUIRE_BASE_URL,
-            )
+            if require_settings.REQUIRE_BUILD_PROFILE is not False:
+                if require_settings.REQUIRE_BUILD_PROFILE is not None:
+                    app_build_js_path = env.compile_dir_path(require_settings.REQUIRE_BUILD_PROFILE)
+                else:
+                    app_build_js_path = env.resource_path("app.build.js")
+                env.run_optimizer(
+                    app_build_js_path,
+                    dir = env.build_dir,
+                    appDir = env.compile_dir,
+                    baseUrl = require_settings.REQUIRE_BASE_URL,
+                )
             # Compile standalone modules.
             if require_settings.REQUIRE_STANDALONE_MODULES:
                 shutil.copyfile(
@@ -125,7 +128,7 @@ class OptimizedFilesMixin(object):
                         baseUrl = os.path.join(env.compile_dir, require_settings.REQUIRE_BASE_URL),
                     )
                 else:
-                    raise ImproperlyConfigured(u"No 'out' option specified for module '{module}' in REQUIRE_STANDALONE_MODULES setting.".format(
+                    raise ImproperlyConfigured("No 'out' option specified for module '{module}' in REQUIRE_STANDALONE_MODULES setting.".format(
                         module = standalone_module
                     ))
             # Update assets with modified ones.
